summaryrefslogtreecommitdiff
path: root/svx/source/fmcomp
diff options
context:
space:
mode:
authorFrank Schönheit <fs@openoffice.org>2002-03-14 15:06:36 +0000
committerFrank Schönheit <fs@openoffice.org>2002-03-14 15:06:36 +0000
commit0eeffcab7a01c2b0caf61c4f9fd20f1c55636fb9 (patch)
tree6275c10027abb0130cf5034e3ffd08f7abf47f55 /svx/source/fmcomp
parent199c91f2606e5f18e204abdb7bd08196da94c16b (diff)
#98166# no commit when dispatching the undoRecord URL to the external dispatcher
Diffstat (limited to 'svx/source/fmcomp')
-rw-r--r--svx/source/fmcomp/fmgridif.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/svx/source/fmcomp/fmgridif.cxx b/svx/source/fmcomp/fmgridif.cxx
index a39d7e1db79c..0371b8e45826 100644
--- a/svx/source/fmcomp/fmgridif.cxx
+++ b/svx/source/fmcomp/fmgridif.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmgridif.cxx,v $
*
- * $Revision: 1.24 $
+ * $Revision: 1.25 $
*
- * last change: $Author: fs $ $Date: 2002-03-06 14:59:47 $
+ * last change: $Author: fs $ $Date: 2002-03-14 16:06:36 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -2774,8 +2774,8 @@ IMPL_LINK(FmXGridPeer, OnExecuteGridSlot, void*, pSlot)
{
if (m_pDispatchers[i].is())
{
- // commit any changes done so far
- if ( commit() )
+ // commit any changes done so far, if it's not the undoRecord URL
+ if ( 0 == pUrls->Complete.compareToAscii( FMURL_RECORD_UNDO ) || commit() )
m_pDispatchers[i]->dispatch(*pUrls, Sequence< PropertyValue>());
return 1; // handled